==> duowen_agent-0.1.37-py3-none-any.whl: duowen_agent/tools/tavily_search.py <==
import logging
from os import getenv
from typing import Literal, Optional, Sequence

from pydantic import BaseModel, Field
from tavily import TavilyClient

from duowen_agent.tools.base import Tool


class TavilyParameters(BaseModel):
    """Parameters definition for Tavily Search API"""

    query: str = Field(description="用户需要搜索的查询字符串")
    search_depth: Literal["basic", "advanced"] = Field(
        default="basic",
        description="搜索深度模式，basic=基础搜索（快速响应），advanced=高级搜索（更深入分析）",
    )
    topic: Literal["general", "news"] = Field(
        default="general", description="搜索主题类型，general=综合信息，news=时效性新闻"
    )
    days: int = Field(
        default=3,
        ge=1,
        description="搜索结果时间范围（仅限news主题），单位天数，默认最近3天",
    )
    max_results: int = Field(
        default=5, ge=1, le=20, description="最大返回结果数量（1-20之间）"
    )
    include_domains: Optional[Sequence[str]] = Field(
        default=None, description="指定需要搜索的域名列表（如['wikipedia.org']）"
    )
    exclude_domains: Optional[Sequence[str]] = Field(
        default=None, description="需要排除的域名列表（如['twitter.com']）"
    )
    include_answer: bool = Field(
        default=False, description="是否在结果中包含AI生成的答案摘要"
    )
    include_raw_content: bool = Field(
        default=False, description="是否包含网页原始内容（可能影响响应速度）"
    )
    include_images: bool = Field(default=False, description="是否在结果中返回图片链接")


class Tavily(Tool):

    name: str = "tavily-search-api"
    description: str = (
        "专业网络搜索引擎，支持深度内容抓取和定制过滤。"
        "优势：精准的来源控制、时效性筛选、结构化数据输出。"
        "适用场景：新闻追踪、学术研究、市场分析等需要最新网络信息的任务。"
    )
    parameters: BaseModel = TavilyParameters

    def __init__(self, api_key: str = None):
        super().__init__()
        self.tavily_client = TavilyClient(api_key or getenv("TAVILY_API_KEY"))

    def search(
        self,
        query: str,
        search_depth: Literal["basic", "advanced"] = "advanced",
        **kwargs,
    ):
        try:
            response = self.tavily_client.search(
                query=query, search_depth=search_depth, **kwargs
            )
            return [
                {
                    "url": res["url"],
                    "title": res["title"],
                    "content": res["content"],
                    "score": res["score"],
                    "content_with_weight": f'URL:{res["url"]}\nTITLE: {res["title"]}\nCONTENT: {res["content"]}\n\n',
                }
                for res in response["results"]
            ]
        except Exception as e:
            logging.exception(e)

        return []

    def _run(
        self,
        query: str,
        search_depth: Literal["basic", "advanced"] = "advanced",
        **kwargs,
    ):
        return self.search(query, search_depth=search_depth, **kwargs)

==> duowen_agent-0.1.42-py3-none-any.whl: duowen_agent/tools/tavily_search.py <==
import logging
from os import getenv
from typing import Literal, Optional, Sequence

from pydantic import BaseModel, Field
from tavily import TavilyClient

from duowen_agent.tools.base import Tool


class TavilyParameters(BaseModel):
    """Parameters definition for Tavily Search API"""

    query: str = Field(description="用户需要搜索的查询字符串")
    search_depth: Literal["basic", "advanced"] = Field(
        default="basic",
        description="搜索深度模式，basic=基础搜索（快速响应），advanced=高级搜索（更深入分析）",
    )
    topic: Literal["general", "news"] = Field(
        default="general", description="搜索主题类型，general=综合信息，news=时效性新闻"
    )
    days: int = Field(
        default=3,
        ge=1,
        description="搜索结果时间范围（仅限news主题），单位天数，默认最近3天",
    )
    max_results: int = Field(
        default=5, ge=1, le=20, description="最大返回结果数量（1-20之间）"
    )
    include_domains: Optional[Sequence[str]] = Field(
        default=None, description="指定需要搜索的域名列表（如['wikipedia.org']）"
    )
    exclude_domains: Optional[Sequence[str]] = Field(
        default=None, description="需要排除的域名列表（如['twitter.com']）"
    )
    include_answer: bool = Field(
        default=False, description="是否在结果中包含AI生成的答案摘要"
    )
    include_raw_content: bool = Field(
        default=False, description="是否包含网页原始内容（可能影响响应速度）"
    )
    include_images: bool = Field(default=False, description="是否在结果中返回图片链接")


class Tavily(Tool):

    name: str = "tavily-search-api"
    description: str = (
        "专业网络搜索引擎，支持深度内容抓取和定制过滤。"
        "优势：精准的来源控制、时效性筛选、结构化数据输出。"
        "适用场景：新闻追踪、学术研究、市场分析等需要最新网络信息的任务。"
    )
    parameters = TavilyParameters

    def __init__(self, api_key: str = None):
        super().__init__()
        self.tavily_client = TavilyClient(api_key or getenv("TAVILY_API_KEY"))

    def search(
        self,
        query: str,
        search_depth: Literal["basic", "advanced"] = "advanced",
        **kwargs,
    ):
        try:
            response = self.tavily_client.search(
                query=query, search_depth=search_depth, **kwargs
            )
            return [
                {
                    "url": res["url"],
                    "title": res["title"],
                    "content": res["content"],
                    "score": res["score"],
                    "content_with_weight": f'URL:{res["url"]}\nTITLE: {res["title"]}\nCONTENT: {res["content"]}\n\n',
                }
                for res in response["results"]
            ]
        except Exception as e:
            logging.exception(e)

        return []

    def _run(
        self,
        query: str,
        search_depth: Literal["basic", "advanced"] = "advanced",
        **kwargs,
    ):
        return self.search(query, search_depth=search_depth, **kwargs)
